@@ -7,9 +7,10 @@ from wave import __version__ as version
 
 
 class TestHelp(TestCase):
-    """Test cases for wavefront cli"""
+    """Test cases for wavefront cli."""
+
     def test_returns_usage_information(self):
-        """Test wavefront cli help command"""
+        """Test wavefront cli help command."""
         output = Popen(['wave', '-h'], stdout=PIPE).communicate()[0]
         self.assertTrue('Usage:' in output)
 
@@ -18,8 +19,9 @@ class TestHelp(TestCase):
 
 
 class TestVersion(TestCase):
-    """Test cases for wavefront cli"""
+    """Test cases for wavefront cli."""
+
     def test_returns_version_information(self):
-        """Test wavefront cli version command"""
+        """Test wavefront cli version command."""
         output = Popen(['wave', '--version'], stdout=PIPE).communicate()[0]
         self.assertEqual(output.strip(), version)
